<?php

class MoYm_Customer_Action{
	
	public function register($POST){

        $email           = '';
        $password        = '';
        $confirmPassword = '';
        $illegal = "#$%^*()+=[]';,/{}|:<>?~";
        $illegal = $illegal . '"';
        if( moym_check_empty_or_null($POST['email']) || moym_check_empty_or_null($POST['password']) || moym_check_empty_or_null($POST['confirmPassword']) ) {
            update_option( 'moym_message', 'All the fields are required. Please enter valid entries.');
            moym_show_error_message();
            return;
        } else if( (strlen($POST['password']) < 6) || (strlen($POST['confirmPassword'])  < 6) ){	//check password is of minimum length 6
            update_option( 'moym_message', 'Choose a password with minimum length 6.');
            moym_show_error_message();
            return;
        } else if(strpbrk($POST['email'],$illegal) ){
            update_option('moym_message', 'Please match the format of Email. No special characters are allowed.');
            moym_show_error_message();
            return;
        } else {
            $email           = sanitize_email($POST['email']);
            $password        = stripslashes( htmlspecialchars($POST['password'] ));
            $confirmPassword = stripslashes( htmlspecialchars($POST['confirmPassword'] ));
        }
        update_option( 'moym_admin_email', $email );

        if ( strcmp( $password, $confirmPassword ) == 0 ) {

            update_option( 'moym_admin_password', $password );
            $customer = new MoYm_Customer();
            $content = json_decode($customer->check_customer(), true);

            if(!is_null($content)) {

                if ( strcasecmp( $content['status'], 'CUSTOMER_NOT_FOUND' ) == 0 ) {

                    $response = $this->moym_create_customer();

                    if(is_array($response) && array_key_exists('status', $response) && $response['status'] == 'success'){
                        update_option( 'moym_message', 'Customer registered successfully.' );
                        moym_show_success_message();
                    }
                    else{
                        update_option( 'moym_message', 'This is not a valid email. Please enter a valid email.' );
                        moym_show_error_message();
                    }
                }
                else if(strcasecmp($content['status'], 'INVALID_EMAIL') == 0){
                    update_option( 'moym_message', 'This is not a valid email. Please enter a valid email.' );
                    moym_show_error_message();
                }
                else {
                    $response = $this->moym_get_current_customer();
                    if(is_array($response) && array_key_exists('status', $response) && $response['status'] == 'success'){
                        update_option( 'moym_message', 'Customer Retrieved Successfully.' );
                        moym_show_success_message();
                    }
                }
            }
        }
        else {
            update_option( 'moym_message', 'Passwords do not match.' );
            delete_option( 'moym_verify_customer' );
            delete_option('moym_admin_customer_key');
            moym_show_error_message();
        }
	}

	public function login($POST){
		//validation and sanitization
		$email = '';
		$password = '';
		$illegal = "#$%^*()+=[]';,/{}|:<>?~";
		$illegal = $illegal . '"';
		if( moym_check_empty_or_null($POST['email']) || moym_check_empty_or_null($POST['password']) ) {
			update_option( 'moym_message', 'All the fields are required. Please enter valid entries.');
			moym_show_error_message();
			return;
		} else if(strpbrk( $POST['email'],$illegal)) {
			update_option( 'moym_message', 'Please match the format of Email. No special characters are allowed.');
			moym_show_error_message();
			return;
		} else if( moym_check_password_pattern($POST['password']) ){
            update_option( 'moym_message', 'Minimum 6 characters should be present. Maximum 15 characters should be present. Only following symbols (!@#.$%^&*-_) should be present.' );
            moym_show_error_message();
            return;
        }
		else{
			$email = sanitize_email( $POST['email'] );
			$password = stripslashes(htmlspecialchars( $POST['password'] ));
		}

		update_option( 'moym_admin_email', $email );
		update_option( 'moym_admin_password', $password );
		$customer = new MoYm_Customer();
		$content = $customer->get_customer_key();

        if(!is_null($content)) {
            $customerKey = json_decode($content, true);
            if (json_last_error() == JSON_ERROR_NONE) {
                update_option('moym_admin_customer_key', $customerKey['id']);
                update_option('moym_admin_api_key', $customerKey['apiKey']);
                update_option('moym_customer_token', $customerKey['token']);
                update_option('moym_admin_password', '');
                update_option('moym_message', 'Your account has been retrieved successfully.');
                delete_option('moym_verify_customer');
                moym_show_success_message();
            } else {
                delete_option('moym_admin_customer_key');
                update_option('moym_message', 'Invalid username or password. Please try again.');
                moym_show_error_message();
            }
        }
		update_option('moym_admin_password', '');
	}

	public function forgot_password($POST){
		$email = get_option('moym_admin_email');
		if( moym_check_empty_or_null( $email ) ) {
			if( moym_check_empty_or_null( $POST['email'] ) ) {
				update_option( 'moym_message', 'No email provided. Please enter your email below to reset password.');
				moym_show_error_message();
				return;
			} else {
				$email = sanitize_email($POST['email']);
			} 
		}
		$customer = new MoYm_Customer();
		$content = json_decode($customer->forgot_password($email),true);
		if(strcasecmp($content['status'], 'SUCCESS') == 0){
			update_option( 'moym_message','You password has been reset successfully. Please enter the new password sent to your registered mail here.');
			moym_show_success_message();
		}else{
			update_option( 'moym_message','An error occured while processing your request. Please make sure you are registered with miniOrange with the given email address.');
			moym_show_error_message();
		}
	}

	public function contact_us($POST){
		// Contact Us query
		$email = sanitize_email($POST['moym_contact_us_email']);
		$phone = htmlspecialchars($POST['moym_contact_us_phone']);
		$query = sanitize_text_field($POST['moym_contact_us_query']);
		$customer = new MoYm_Customer();
		if ( moym_check_empty_or_null( $email ) || moym_check_empty_or_null( $query ) ) {
			update_option('moym_message', 'Please fill up Email and Query fields to submit your query.');
			moym_show_error_message();
		} else {
			$submited = $customer->submit_contact_us( $email, $phone, $query );
			if ( $submited == false ) {
				update_option('moym_message', 'Your query could not be submitted. Please try again.');
				moym_show_error_message();
			} else {
				update_option('moym_message', 'Thanks for getting in touch! We shall get back to you shortly.');
				moym_show_success_message();
			}
		}
	}

	public function go_back_registration($POST){
		update_option('moym_registration_status','');
		delete_option('moym_new_registration');
		delete_option('moym_admin_email');
		delete_option('moym_verify_customer');
	}

    public function go_back_login($POST){
        delete_option( 'moym_new_registration' );
        update_option( 'moym_verify_customer', 'true' );
    }

	function moym_create_customer(){
		$customer = new MoYm_Customer();
		$customerKey = json_decode( $customer->create_customer(), true );
        if(!is_null($customerKey)) {
            $response = array();
            if (strcasecmp($customerKey['status'], 'CUSTOMER_USERNAME_ALREADY_EXISTS') == 0) {
                $api_response = $this->moym_get_current_customer();
                if ($api_response) {
                    $response['status'] = "success";
                } else
                    $response['status'] = "error";
            } else if (strcasecmp($customerKey['status'], 'SUCCESS') == 0) {
                update_option('moym_admin_customer_key', $customerKey['id']);
                update_option('moym_admin_api_key', $customerKey['apiKey']);
                update_option('moym_customer_token', $customerKey['token']);
                update_option('moym_admin_password', '');
                update_option('moym_message', 'Registration complete!');
                update_option('moym_registration_status', 'mo_ym_REGISTRATION_COMPLETE');
                delete_option('moym_verify_customer');
                delete_option('moym_new_registration');
                moym_show_success_message();
                $response['status'] = "success";
                return $response;
            }
            update_option('moym_admin_password', '');
            return $response;
        }
	}

	function moym_get_current_customer(){
		$customer = new MoYm_Customer();
		$content = $customer->get_customer_key();
		$customerKey = json_decode( $content, true );

		if( isset($customerKey) ) {
			update_option( 'moym_admin_customer_key', $customerKey['id'] );
			update_option( 'moym_admin_api_key', $customerKey['apiKey'] );
			update_option( 'moym_customer_token', $customerKey['token'] );
			update_option('moym_admin_password', '' );
			update_option( 'moym_message', 'Your account has been retrieved successfully.' );
			delete_option('moym_verify_customer');
			delete_option('moym_new_registration');
            moym_show_success_message();
            $response['status'] = "success";
            return $response;
		} else {
			update_option( 'moym_message', 'You already have an account with miniOrange. Please enter a valid password.');
			update_option('moym_verify_customer', 'true');
			delete_option('moym_new_registration');
			delete_option('moym_admin_customer_key');
			moym_show_error_message();
            $response['status'] = "error";
            return $response;
		}

	}

    function skip_feedback(){
        update_option( 'moym_message', 'Plugin deactivated successfully' );
        moym_show_success_message();
        deactivate_plugins( 'login-with-yourmembership/moym_settings.php' );
    }

	public function send_feedback($POST){
        $user = wp_get_current_user();
        $message = 'Plugin Deactivated';
        $deactivate_reason_message = array_key_exists( 'query_feedback', $POST ) ? htmlspecialchars($POST['query_feedback']) : false;
        
        if(is_multisite())
            $multisite_enabled = 'True';
        else
            $multisite_enabled = 'False';

        $message.= ', [Multisite enabled: ' . $multisite_enabled .']';
        $message.= ', Feedback : '.$deactivate_reason_message.'';

        if (isset($POST['rate']))
            $rate_value = htmlspecialchars($POST['rate']);

        $message.= ', [Rating :'.$rate_value.']';

        $email = $POST['query_mail'];
        if(!filter_var($email, FILTER_VALIDATE_EMAIL)){
            $email = get_option('moym_admin_email');
            if(empty($email))
                $email = $user->user_email;
        }
        $phone = get_option( 'moym_admin_phone' );
        $feedback_reasons = new MoYm_Customer();
        if(!is_null($feedback_reasons)){
            $submited = json_decode( $feedback_reasons->send_email_alert( $email, $phone, $message ), true );
            if ( json_last_error() == JSON_ERROR_NONE ) {
                if ( is_array( $submited ) && array_key_exists( 'status', $submited ) && $submited['status'] == 'ERROR' ) {
                    update_option( 'moym_message', $submited['message'] );
                    moym_show_success_message();
                }
                else {
                    if ( $submited == false ) {
                        update_option( 'moym_message', 'Error while submitting the query.' );
                        moym_show_error_message();
                    }
                }
            }
            update_option( 'moym_message', 'Thank you for the feedback.' );
            moym_show_success_message();
            deactivate_plugins( 'login-with-yourmembership/moym_settings.php' );
        }
    }

}

?>