<?php

require('includes/classes/moym_login_widget.php');
require('includes/tmpl/moym_feedback.php');

class MoYm_Sso{

    private $url, $version, $apiKey, $retURL;

    function __construct(){

        $this->url = 'https://api.yourmembership.com';
        $this->version = '2.30';
        
        add_action( 'init', array( $this, 'moym_validate' ));
        add_action( 'admin_footer', array( $this, 'moym_feedback' ) );
        add_action( 'widgets_init',function(){register_widget( "MoYm_Login_Widget" );} );

        if( ! session_id() || session_id() == '' || !isset($_SESSION) ) {
            session_start();
        }
    }

    public function moym_validate(){
        $redirect_to = '';
        if (isset( $_REQUEST['option'] ) and strpos( $_REQUEST['option'], 'moymsso' ) !== false ){
            if(isset($_REQUEST['testconfig']) && $_REQUEST['testconfig'] == 'true'){
                $_SESSION['moymtest'] = true;
            }
            $this->moym_authorize_user();
        } else if (isset( $_REQUEST['option'] ) and strpos( $_REQUEST['option'], 'show_attr' ) !== false) {
            $basicProfile = get_option('moym_basic_profile');
            echo '<pre>';
            var_export(maybe_unserialize((array)$basicProfile));
            session_destroy();
            echo '</pre>';exit;
        }
        else if (isset($_REQUEST['code'])) {
	        $moym_code = trim($_REQUEST['code']);
	        $this->moym_user_auth($moym_code);
        }
    }

	function moym_authorize_user(){
		$authURL = get_option('moym_authURL');
		$appID = get_option('moym_appID');
		$callbackURL = get_option('moym_callback');
		$authorizationURL = $authURL . "?app_id=" . $appID ."&redirect_uri=". $callbackURL . "/&scope=basic_profile";
        
		wp_redirect($authorizationURL); exit;
	}

	function moym_user_auth($moym_code){
		$moym_appid = get_option('moym_appID');
		$moym_app_secret = get_option('moym_app_secret');
		$moym_clientid = get_option('moym_clientID');
		$moym_user_type = 'Member';

		if(empty($moym_code)){
			echo 'ERROR: No Authorization Code found';
			exit;
		}

		$access_token_response = json_decode($this->moym_get_access_token($moym_appid,$moym_app_secret,$moym_code));
		$moym_access_token = $access_token_response->AccessToken;

		if(empty($moym_access_token)){
			echo 'ERROR: Access Token not found';
			exit;
		}

		$moym_session_value = json_decode($this->moym_authenticate_user($moym_appid,$moym_app_secret,$moym_access_token,$moym_clientid,$moym_user_type));
		$moym_sessionid = $moym_session_value->SessionId;
		$moym_memberid = $moym_session_value->MemberID;

		if(empty($moym_sessionid) || empty($moym_memberid)){
			echo 'ERROR: Session information not found';
			exit;
		}

		$basicProfile = json_decode($this->moym_get_user_basic_profile($moym_sessionid, $moym_memberid, $moym_clientid));
        
        update_option('moym_basic_profile',$basicProfile);

        $firstName = '';
        $lastName = '';
		$email = '';
		if(isset($basicProfile->FirstName))
			$firstName = $basicProfile->FirstName;
		if(isset($basicProfile->LastName))
			$lastName = $basicProfile->LastName;
		if(isset($basicProfile->Email))
			$email = $basicProfile->Email;


        if( isset($_SESSION['moymtest']) &&  $_SESSION['moymtest']=='true') {
            $redirect_url = site_url();
            wp_redirect($redirect_url."?option=show_attr");exit;
        }

		$this->moym_new_user_login($email, $firstName, $lastName, $moym_sessionid);
	}

	function moym_new_user_login($email_addr, $firstName, $lastName, $moym_sessionid){

		$userName = $email_addr;
		$email = $email_addr;
		$displayName = $firstName.' '.$lastName;
		$newUser = 'false';

		if(username_exists($userName) || email_exists($email)) {    //user is a member

			$user_id='';
			if(username_exists($userName)){
				$user = get_user_by('login', $userName);
				$user_id = $user->ID;
				if(!empty($email))
					wp_update_user(array('ID' => $user_id, 'user_email' => $email));
			} else if(email_exists($email)){
				$user 	= get_user_by('email', $email );
				$user_id = $user->ID;
			}

		} else {                                                                                  //this user is a new user
			$random_password = wp_generate_password(10, false);
            $newUser = 'true';

			if(!empty($userName))
				$user_id = wp_create_user($userName, $random_password, $email);
			else {
				wp_die('We could not sign you in. Please contact your administrator.', 'No Username received.');
				exit();
			}
		}

        $this->moym_map_basic_attributes($user_id, $firstName, $lastName, $displayName);
        $this->moym_create_auth_token($userName, $newUser);

		$redirect_url = site_url();
		wp_redirect($redirect_url);
		exit;
	}

	function moym_map_basic_attributes($user_id, $firstName, $lastName, $displayName){

		if(!empty($first_name))
		    wp_update_user(array('ID' => $user_id, 'first_name' => $first_name));
		if(!empty($last_name))
			wp_update_user(array('ID' => $user_id, 'last_name' => $last_name));
		if(!empty($display_name))
			wp_update_user(array('ID' => $user_id, 'display_name' => $display_name));

	}

    function moym_create_auth_token($username, $newUser){

        $user = get_user_by('login', $username);

        if($newUser)
            do_action( 'user_register', $user->ID);

        do_action('wp_login', $user->user_login, $user);
        wp_set_auth_cookie($user->ID, true);
    }

	function moym_get_access_token($appID, $app_secret, $code){

		global $moym_api_host;
		$url = $moym_api_host .'/OAuth/GetAccessToken';
		$fields = array (
			'AppID' => $appID,
			'AppSecert' => $app_secret,
			'GrantType' => 'Code',
			'Code' => $code
		);

		$headers = array('Accept'=>'application/json', 'Cookie' => 'ss-id=41POeyfOt1rfuE3zudex; ss-pid=uXiKrjunYce4x2A66jq4; X-UAId=ae1c6f0b-7413-40fe-b650-5e6d9da36859; .Stackify.Rum=930e9203-2700-4c03-a65d-9e80cd148840');              //Discuss: What headers should be added
		$args = $this->moym_get_arguments($fields, $headers);
		$response = moym_wp_remote_call($url, $args);
		return $response;
	}

	function moym_authenticate_user($moym_appID,$moym_app_secret,$moym_access_token,$moym_clientID,$moym_user_type){

		global $moym_api_host;
		$url = $moym_api_host .'/Ams/Authenticate';
		$fields = array (
			'ConsumerKey' => $moym_appID,
			'ConsumerSecret' => $moym_app_secret,
			'AccessToken' => $moym_access_token,
			'ClientID' => $moym_clientID,
			'UserType' => $moym_user_type
		);

		$headers = array("Accept"=>"application/json", 'Cookie' => 'ss-pid=uXiKrjunYce4x2A66jq4');
		$args = $this->moym_get_arguments($fields, $headers);
		$response = moym_wp_remote_call($url, $args);
		return $response;
	}

	function moym_get_arguments($fields, $headers){
		$args = array(
			'method' => 'POST',
			'body' => $fields,
			'timeout' => '5',
			'redirection' => '10',
			'httpversion' => '1.1',
			'blocking' => true,
			'headers' => $headers
		);
		return $args;
	}

	function moym_get_user_basic_profile($moym_sessionid, $moym_memberid, $moym_clientid){

		global $moym_api_host;
		$url = $moym_api_host . '/Ams/'.$moym_clientid.'/Member/'.$moym_memberid.'/BasicMemberProfile';

		$args = array(
			'headers' => array(
				'Content-Type' => 'application/json',
				'X-SS-ID' => $moym_sessionid
			)
		);

		$response = moym_wp_remote_call($url, $args, true);
		return $response;
	}

    public function moym_feedback(){
        moym_feedback_form();
    }

	

	
	

}